@@ -5,6 +5,7 @@ from pyage.core import address
 from pyage.core.agent import  agents_factory
 from pyage.core.locator import Pyro4Locator
 from pyage.core.migration import NoMigration
+from pyage.core.statistics import SimpleStatistics
 from pyage.solutions.evolution.crossover import AverageCrossover
 from pyage.solutions.evolution.evaluation import RastriginEvaluation
 from pyage.solutions.evolution.initializer import PointInitializer
@@ -27,3 +28,4 @@ daemon = lambda: pyro_daemon
 
 ns_hostname = lambda: "192.168.0.103"
 
+stats = SimpleStatistics
